package com.jkcredit.illegal.info.task;

import com.jkcredit.illegal.info.constant.CommonConstant;
import com.jkcredit.illegal.info.model.SendDingMsgResponseObject;
import com.jkcredit.illegal.info.util.DingRobotUtil;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.util.Objects;

/**
 * @author xusonglin
 * @version V1.0
 **/
@Component
@Slf4j
public class ExceptionListenerTask {
    @Autowired
    StringRedisTemplate stringRedisTemplate;

    @XxlJob("personIllegalInfoTask")
    public ReturnT<String> personIllegalInfoTask(String param) {
        int timeOutCount = 0;
        int queryFailedCount = 0;
        String timeOut = stringRedisTemplate.boundValueOps(CommonConstant.PERSON_ILLEGAL_INFO_TIME_OUT).get();
        String queryFailed = stringRedisTemplate.boundValueOps(CommonConstant.PERSON_ILLEGAL_INFO_QUERY_FAILED).get();
        if (timeOut != null) {
            timeOutCount = Integer.parseInt(timeOut);
        }
        if (queryFailed != null) {
            queryFailedCount = Integer.parseInt(queryFailed);
        }

        String errorMessage = "社会风险预警-人员核验接口失败，失败原因：";
        if (timeOutCount > 10) {
            errorMessage += "数据源超时";
            SendDingMsgResponseObject sendDingMsgResponseObject = DingRobotUtil.sendDingRobotMsg(errorMessage);
            if (sendDingMsgResponseObject.getCode() != 1) {
                log.info("personIllegalInfoTask, 发送钉钉异常：社会风险预警-人员核验接口失败-数据源超时");
            }
        }

        if (queryFailedCount >10) {
            errorMessage += "数据源返回结果异常";
            SendDingMsgResponseObject sendDingMsgResponseObject = DingRobotUtil.sendDingRobotMsg(errorMessage);
            if (sendDingMsgResponseObject.getCode() != 1) {
                log.info("personIllegalInfoTask, 发送钉钉异常：社会风险预警-人员核验接口失败-数据源返回结果异常");
            }
        }
        stringRedisTemplate.delete(CommonConstant.PERSON_ILLEGAL_INFO_TIME_OUT);
        stringRedisTemplate.delete(CommonConstant.PERSON_ILLEGAL_INFO_QUERY_FAILED);
        return ReturnT.SUCCESS;
    }

    @XxlJob("vehicleIllegalInfoTask")
    public ReturnT<String> vehicleIllegalInfoTask(String param) {
        int timeOutCount = 0;
        int queryFailedCount = 0;
        String timeOut = stringRedisTemplate.boundValueOps(CommonConstant.VEHICLE_ILLEGAL_INFO_TIME_OUT).get();
        String queryFailed = stringRedisTemplate.boundValueOps(CommonConstant.VEHICLE_ILLEGAL_INFO_QUERY_FAILED).get();
        if (timeOut != null) {
            timeOutCount = Integer.parseInt(timeOut);
        }
        if (queryFailed != null) {
            queryFailedCount = Integer.parseInt(queryFailed);
        }

        String errorMessage = "社会风险预警-车辆核验接口失败，失败原因：";
        if (timeOutCount > 10) {
            errorMessage += "数据源超时";
            SendDingMsgResponseObject sendDingMsgResponseObject = DingRobotUtil.sendDingRobotMsg(errorMessage);
            if (sendDingMsgResponseObject.getCode() != 1) {
                log.info("vehicleIllegalInfoTask, 发送钉钉异常：社会风险预警-车辆核验接口失败-数据源超时");
            }
        }

        if (queryFailedCount >10) {
            errorMessage += "数据源返回结果异常";
            SendDingMsgResponseObject sendDingMsgResponseObject = DingRobotUtil.sendDingRobotMsg(errorMessage);
            if (sendDingMsgResponseObject.getCode() != 1) {
                log.info("vehicleIllegalInfoTask, 发送钉钉异常：社会风险预警-车辆核验接口失败-数据源返回结果异常");
            }
        }
        stringRedisTemplate.delete(CommonConstant.VEHICLE_ILLEGAL_INFO_TIME_OUT);
        stringRedisTemplate.delete(CommonConstant.VEHICLE_ILLEGAL_INFO_QUERY_FAILED);
        return ReturnT.SUCCESS;
    }

    @XxlJob("dingdingTestTask")
    public ReturnT<String> dingdingTestTask(String param) {
        String message = "社会风险预警-测试";
        SendDingMsgResponseObject sendDingMsgResponseObject = DingRobotUtil.sendDingRobotMsg(message);
        return ReturnT.SUCCESS;
    }
}
